OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure en la carpeta \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Això normalment es pot solucionar donant al servidor web accés d'escriptura a la carpeta de configuració.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O bé, si preferiu mantenir el fitxer config.php només de lectura, establir l'opció \"config_is_read_only\" com a cert.",
    "See %s" : "Consulteu %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Falta l'aplicació %1$s o té una versió no compatible amb aquest servidor. Comproveu la carpeta d'aplicacions.",
    "Sample configuration detected" : "S'ha detectat una configuració d'exemple",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que s'ha copiat la configuració d'exemple. Això no s'admet i pot malmetre la instal·lació. Llegiu la documentació abans d'aplicar cap canvi al fitxer config.php",
    "The page could not be found on the server." : "No s'ha pogut trobar la pàgina en el servidor.",
    "%s email verification" : "Verificació de l'adreça electrònica del %s",
    "Email verification" : "Verificació de l'adreça electrònica",
    "Click the following button to confirm your email." : "Feu clic en el botó següent per a confirmar la vostra adreça electrònica.",
    "Click the following link to confirm your email." : "Feu clic en l'enllaç següent per a confirmar la vostra adreça electrònica.",
    "Confirm your email" : "Confirma l'adreça electrònica",
    "Other activities" : "Altres activitats",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education bundle" : "Paquet d'educació",
    "Enterprise bundle" : "Paquet empresarial",
    "Groupware bundle" : "Paquet de treball en grup",
    "Hub bundle" : "Paquet Hub",
    "Public sector bundle" : "Paquet del sector públic",
    "Social sharing bundle" : "Paquet social",
    "PHP %s or higher is required." : "Cal el PHP %s o superior.",
    "PHP with a version lower than %s is required." : "Cal el PHP amb una versió inferior a la %s.",
    "%sbit or higher PHP required." : "Cal el PHP de %s bits o superior.",
    "The following architectures are supported: %s" : "S'admeten les arquitectures següents: %s",
    "The following databases are supported: %s" : "S'admeten les bases de dades següents: %s",
    "The command line tool %s could not be found" : "No s'ha trobat l'eina de línia d'ordres %s",
    "The library %s is not available." : "La biblioteca %s no està disponible.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Cal la biblioteca %1$s amb una versió superior a la %2$s; la versió disponible és la %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Cal la biblioteca %1$s amb una versió inferior a la %2$s; la versió disponible és la %3$s.",
    "The following platforms are supported: %s" : "S'admeten les plataformes següents: %s",
    "Server version %s or higher is required." : "Cal la versió del servidor %s o superior.",
    "Server version %s or lower is required." : "Cal una versió del servidor %s o inferior.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "El compte que ha iniciat la sessió ha de ser administrador, subadministrador o tenir un dret especial per a accedir a aquest paràmetre",
    "Logged in account must be an admin or sub admin" : "El compte que ha iniciat la sessió ha de ser administrador o subadministrador",
    "Logged in account must be an admin" : "El compte que ha iniciat la sessió ha de ser administrador",
    "Wiping of device %s has started" : "S'ha començat a esborrar el dispositiu %s",
    "Wiping of device »%s« has started" : "S'ha començat a esborrar el dispositiu «%s»",
    "»%s« started remote wipe" : "«%s» ha començat a esborrar dades en remot",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositiu o aplicació »%s«  ha començat a esborrar les dades en remot. Rebreu un altre correu quan s'enllesteixi el procés",
    "Wiping of device %s has finished" : "S'ha acabat d'esborrar el dispositiu %s",
    "Wiping of device »%s« has finished" : "S'ha acabat d'esborrar el dispositiu «%s»",
    "»%s« finished remote wipe" : "«%s» ha acabat d'esborrar dades en remot",
    "Device or application »%s« has finished the remote wipe process." : "El dispositiu o aplicació «%s» ha acabat d'esborrar les dades en remot.",
    "Remote wipe started" : "S'ha començat a esborrar en remot",
    "A remote wipe was started on device %s" : "S'han començat a esborrar les dades del dispositiu %s en remot",
    "Remote wipe finished" : "S'han acabat d'esborrar les dades en remot",
    "The remote wipe on %s has finished" : "S'han acabat d'esborrar les dades del dispositiu %s en remot",
    "Authentication" : "Autenticació",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "Avatar image is not square" : "La imatge de l'avatar no és quadrada",
    "Files" : "Fitxers",
    "View profile" : "Visualitza el perfil",
    "same time" : "mateix temps",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s endavant",
    "%s behind" : "%s darrere",
    "Local time: %s" : "Hora local: %s",
    "today" : "avui",
    "tomorrow" : "demà",
    "yesterday" : "ahir",
    "_in %n day_::_in %n days_" : ["d'aquí a %n dia","d'aquí a %n dies"],
    "_%n day ago_::_%n days ago_" : ["fa %n dia","fa %n dies"],
    "next month" : "el mes vinent",
    "last month" : "el mes passat",
    "_in %n month_::_in %n months_" : ["d'aquí a %n mes","d'aquí a %n mesos"],
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "next year" : "l'any vinent",
    "last year" : "l'any passat",
    "_in %n year_::_in %n years_" : ["d'aquí a %n any","d'aquí a %n anys"],
    "_%n year ago_::_%n years ago_" : ["fa %n any","fa %n anys"],
    "_in %n hour_::_in %n hours_" : ["d'aquí a %n hora","d'aquí a %n hores"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_in %n minute_::_in %n minutes_" : ["d'aquí a %n minut","d'aquí a %n minuts"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "in a few seconds" : "d'aquí a uns segons",
    "seconds ago" : "fa uns segons",
    "Empty file" : "Fitxer buit",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El mòdul amb l'ID %s no existeix. Habiliteu-lo els paràmetres de les aplicacions o contacteu amb l'administrador.",
    "No file conversion providers available" : "No hi ha proveïdors de conversió de fitxers disponibles",
    "File is too large to convert" : "El fitxer és massa gran per convertir-lo",
    "Destination does not match conversion extension" : "La destinació no coincideix amb l'extensió de conversió",
    "Could not convert file" : "No s'ha pogut convertir el fitxer",
    "Destination does not exist" : "La destinació no existeix",
    "Destination is not creatable" : "La destinació no es pot crear",
    "Dot files are not allowed" : "No es permeten els fitxers que comencen per un punt",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" és un nom de fitxer o carpeta prohibit.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" és un prefix prohibit per als noms de fitxers o carpetes.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" no es permet dins d'un nom de fitxer o carpeta.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" és un tipus de fitxer prohibit.",
    "Filenames must not end with \"%1$s\"." : "Els noms de fitxer no han d'acabar amb \"%1$s\".",
    "Invalid parent path" : "El camí principal no és vàlid",
    "File already exists" : "El fitxer ja existeix",
    "Invalid path" : "El camí no és vàlid",
    "Failed to create file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
    "Templates" : "Plantilles",
    "Storage %s cannot be moved" : "L'emmagatzematge %s no es pot moure",
    "Moving a share (%s) into a shared folder is not allowed" : "No és permès moure una compartició (%s) a una carpeta compartida",
    "Moving a storage (%s) into a shared folder is not allowed" : "No és permès moure un emmagatzematge (%s) a una carpeta compartida",
    "Moving a share (%s) into another share (%s) is not allowed" : "No és permès moure una compartició (%s) a una altra compartició (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "No és permès moure una compartició (%s) a un altre emmagatzematge (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "No és permès moure un emmagatzematge (%s) a una compartició (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "No és permès moure un emmagatzematge (%s) a un altre emmagatzematge (%s)",
    "Path contains invalid segments" : "El camí conté segments no vàlids",
    "Filename is a reserved word" : "El nom del fitxer és una paraula reservada",
    "Filename contains at least one invalid character" : "El nom del fitxer conté com a mínim un caràcter no vàlid",
    "Filename is too long" : "El nom del fitxer és massa llarg",
    "Empty filename is not allowed" : "No es permeten els noms de fitxers buits",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'aplicació «%s» no es pot instal·lar perquè no es pot llegir el fitxer appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'aplicació «%s» no es pot instal·lar perquè no és compatible amb aquesta versió del servidor.",
    "__language_name__" : "Català",
    "This is an automatically sent email, please do not reply." : "Això és un correu electrònic enviat automàticament, no el respongueu.",
    "Help & privacy" : "Ajuda i privadesa",
    "Appearance and accessibility" : "Aspecte i accessibilitat",
    "Apps" : "Aplicacions",
    "Personal settings" : "Paràmetres personals",
    "Administration settings" : "Paràmetres d'administració",
    "Settings" : "Paràmetres",
    "Log out" : "Tanca la sessió",
    "Accounts" : "Comptes",
    "Email" : "Adreça electrònica",
    "Mail %s" : "Envia un correu a %s",
    "Fediverse" : "Fedivers",
    "View %s on the fediverse" : "Visualitza %s en el fedivers",
    "Phone" : "Telèfon",
    "Call %s" : "Truca a %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualitza %s a Twitter",
    "Website" : "Lloc web",
    "Visit %s" : "Visita %s",
    "Address" : "Adreça",
    "Profile picture" : "Foto de perfil",
    "About" : "Quant a",
    "Display name" : "Nom de visualització",
    "Headline" : "Capçalera",
    "Organisation" : "Organització",
    "Role" : "Càrrec",
    "Pronouns" : "Pronoms",
    "Unknown account" : "Compte desconegut",
    "Additional settings" : "Paràmetres addicionals",
    "Enter the database Login and name for %s" : "Introduïu l'inici de sessió i el nom de la base de dades per a %s",
    "Enter the database Login for %s" : "Introduïu l'inici de sessió de la base de dades per a %s",
    "Enter the database name for %s" : "Introduïu el nom de la base de dades per a %s",
    "You cannot use dots in the database name %s" : "No podeu utilitzar punts en el nom de la base de dades %s",
    "MySQL Login and/or password not valid" : "L'inici de sessió o la contrasenya del MySQL no són vàlids",
    "You need to enter details of an existing account." : "Heu d'introduir els detalls d'un compte existent.",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió amb Oracle",
    "Oracle Login and/or password not valid" : "L'inici de sessió o la contrasenya d'Oracle no són vàlids",
    "PostgreSQL Login and/or password not valid" : "L'inici de sessió o la contrasenya del PostgreSQL no són vàlids",
    "For the best results, please consider using a GNU/Linux server instead." : "Per a obtenir els millors resultats, considereu la possibilitat d'utilitzar un servidor amb GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembla que aquesta instància del %s s'està executant en un entorn del PHP de 32 bits i que s'ha configurat open_basedir en el fitxer php.ini. Això comportarà problemes amb els fitxers de més de 4 GB i és molt poc recomanable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Suprimiu el paràmetre open_basedir del fitxer php.ini o canvieu al PHP de 64 bits.",
    "Set an admin Login." : "Definiu un inici de sessió per a l'administrador.",
    "Set an admin password." : "Definiu una contrasenya per a l'administrador.",
    "Cannot create or write into the data directory %s" : "No es pot crear la carpeta de dades %s ni escriure-hi",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons d'ús compartit %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "No s'ha trobat el rerefons d'ús compartit %s",
    "Sharing backend for %s not found" : "No s'ha trobat el rerefons d'ús compartit per a %s",
    "%1$s shared %2$s with you" : "%1$s ha compartit %2$s amb tu",
    "Open %s" : "Obre %s",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s ha compartit %2$s amb tu i vol afegir:",
    "%1$s shared %2$s with you and wants to add" : "%1$s ha compartit %2$s amb tu i vol afegir",
    "%s added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb tu",
    "Passwords are enforced for link and mail shares" : "S'apliquen contrasenyes per compartició d'enllaços i correus",
    "Share recipient is not a valid user" : "El destinatari de la compartició no és un usuari vàlid",
    "Share recipient is not a valid group" : "El destinatari de la compartició no és un grup vàlid",
    "Share recipient should be empty" : "El destinatari de la compartició ha d'estar buit",
    "Share recipient should not be empty" : "El destinatari de la compartició no ha d'estar buit",
    "Share recipient is not a valid circle" : "El destinatari de la compartició no és un cercle vàlid",
    "Unknown share type" : "Tipus de compartició desconegut",
    "Share initiator must be set" : "S'ha d'establir l'iniciador de la compartició",
    "Cannot share with yourself" : "No es pot compartir amb tu mateix",
    "Shared path must be set" : "S'ha d'establir un camí compartit",
    "Shared path must be either a file or a folder" : "El camí compartit ha de ser un fitxer o una carpeta",
    "You cannot share your root folder" : "No podeu compartir la vostra carpeta arrel",
    "You are not allowed to share %s" : "No podeu compartir %s",
    "Valid permissions are required for sharing" : "Es requereixen permisos vàlids per compartir",
    "File shares cannot have create or delete permissions" : "Les comparticions de fitxers no poden tenir permisos de creació o supressió",
    "Cannot increase permissions of %s" : "No es poden augmentar els permisos de %s",
    "Shares need at least read permissions" : "Les comparticions almenys necessiten permisos de lectura",
    "Files cannot be shared with delete permissions" : "No es poden compartir fitxers amb permisos de supressió",
    "Files cannot be shared with create permissions" : "No es poden compartir fitxers amb permisos de creació",
    "Expiration date is in the past" : "La data de caducitat ja ha passat",
    "Expiration date is enforced" : "S'aplica la data de caducitat",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No es pot establir la data de caducitat més d'%n dia en el futur","No es pot establir la data de caducitat més de %n dies en el futur"],
    "Sharing is only allowed with group members" : "Només es permet l'ús compartit amb membres del grup",
    "Sharing %s failed, because this item is already shared with the account %s" : "No s'ha pogut compartir %s perquè l'element ja està compartit amb el compte %s",
    "Group sharing is now allowed" : "Ara es permet compartir en grup",
    "Sharing is only allowed within your own groups" : "La compartició només és permesa dins dels vostres propis grups",
    "Path is already shared with this group" : "El camí ja està compartit amb aquest grup",
    "Link sharing is not allowed" : "La compartició d'enllaços no és permesa",
    "Public upload is not allowed" : "La pujada pública no és permesa",
    "Sharing is disabled" : "S’ha desactivat la compartició",
    "Sharing is disabled for you" : "La compartició està desactivada per a tu",
    "Cannot share with the share owner" : "No es pot compartir amb el propietari de la compartició",
    "Share does not have a full ID" : "La compartició no té un ID complet",
    "Cannot change share type" : "No es pot canviar el tipus de compartició",
    "Can only update recipient on user shares" : "Només es pot actualitzar el destinatari en les comparticions d'usuaris",
    "Cannot enable sending the password by Talk with an empty password" : "No es pot habilitar l'enviament de la contrasenya per Converses amb una contrasenya buida",
    "Cannot enable sending the password by Talk without setting a new password" : "No es pot activar l'enviament de la contrasenya per Converses sense establir una nova contrasenya",
    "Cannot disable sending the password by Talk without setting a new password" : "No es pot desactivar l'enviament de la contrasenya per Converses sense establir una nova contrasenya",
    "Share provider does not support accepting" : "El proveïdor de la compartició no admet l'acceptació",
    "Cannot change target of link share" : "No es pot canviar el destí de l'enllaç de compartició",
    "Invalid share recipient" : "El destinatari de la compartició no és vàlid",
    "Group \"%s\" does not exist" : "El grup \"%s\" no existeix",
    "The requested share does not exist anymore" : "L'element compartit sol·licitat ja no existeix",
    "The requested share comes from a disabled user" : "L'element compartit sol·licitat prové d'un usuari inhabilitat",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "No s'ha creat l'usuari perquè s'ha assolit el límit d'usuaris. Consulteu les notificacions per a obtenir més informació.",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria «%s»",
    "Input text" : "Text d'entrada",
    "The input text" : "El text d'entrada",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sun." : "Dg.",
    "Mon." : "Dl.",
    "Tue." : "Dt.",
    "Wed." : "Dc.",
    "Thu." : "Dj.",
    "Fri." : "Dv.",
    "Sat." : "Ds.",
    "Su" : "Dg",
    "Mo" : "Dl",
    "Tu" : "Dt",
    "We" : "Dc",
    "Th" : "Dj",
    "Fr" : "Dv",
    "Sa" : "Ds",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "Jan." : "Gen.",
    "Feb." : "Febr.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ag.",
    "Sep." : "Set.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Heu de proporcionar una contrasenya vàlida",
    "The Login is already being used" : "L'inici de sessió ja està en ús",
    "Could not create account" : "No s'ha pogut crear el compte",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Només es permeten els caràcters següents en un inici de sessió: «a-z», «A-Z», «0-9», espais i «_.@-'»",
    "A valid Login must be provided" : "Heu de proporcionar un inici de sessió vàlid",
    "Login contains whitespace at the beginning or at the end" : "L'inici de sessió conté espais en blanc al principi o al final",
    "Login must not consist of dots only" : "L'inici de sessió no pot estar format només per punts",
    "Login is invalid because files already exist for this user" : "L'inici de sessió no és vàlid perquè ja existeixen fitxers per a aquest usuari",
    "Account disabled" : "El compte està inhabilitat",
    "Login canceled by app" : "L'aplicació ha cancel·lat l'inici de sessió",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'aplicació «%1$s» no es pot instal·lar perquè no es compleixen les dependències següents: %2$s",
    "a safe home for all your data" : "un lloc segur per a totes les vostres dades",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha caducat. Torneu a carregar la pàgina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No s'ha instal·lat cap controlador de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory." : "No es pot escriure en la carpeta «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Això normalment es pot solucionar donant al servidor web accés d'escriptura a la carpeta de configuració. Consulteu %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O bé, si preferiu mantenir el fitxer config.php només de lectura, establir l'opció «config_is_read_only» com a «true». Consulteu %s",
    "Cannot write into \"apps\" directory." : "No es pot escriure en la carpeta «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Això normalment pot solucionar donant al servidor web accés d'escriptura a la carpeta d'aplicacions o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
    "Cannot create \"data\" directory." : "No es pot crear la carpeta «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Això normalment es pot solucionar donant accés d'escriptura al servidor web a la carpeta arrel. Consulteu %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Els permisos normalment es poden corregir donant accés d'escriptura al servidor web a la carpeta arrel. Consulteu %s.",
    "Your data directory is not writable." : "No es pot escriure en la carpeta de dades.",
    "Setting locale to %s failed." : "No s'ha pogut establir la configuració regional %s.",
    "Please install one of these locales on your system and restart your web server." : "Instal·leu una d'aquestes configuracions regionals en el sistema i reinicieu el servidor web.",
    "PHP module %s not installed." : "El mòdul del PHP %s no està instal·lat.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP setting \"%s\" is not set to \"%s\"." : "El paràmetre del PHP «%s» no està establert en «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Si ajusteu aquest paràmetre en el fitxer php.ini, el Nextcloud tornarà a funcionar",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> té el valor <code>%s</code> en comptes del valor esperat <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Per a resoldre aquest problema, establiu <code>mbstring.func_overload</code> en <code>0</code> en el fitxer php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembla que el PHP està configurat per a suprimir els blocs de documentació entre línies. Això farà que diverses aplicacions principals no siguin accessibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement és provocat per un mecanisme de memòria cau o accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls del PHP, però encara apareixen com si no hi fossin?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reiniciï el servidor web.",
    "The required %s config variable is not configured in the config.php file." : "No s'ha configurat la variable obligatòria %s en el fitxer config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Demaneu a l'administrador del servidor que comprovi la configuració del Nextcloud.",
    "Your data directory is readable by other people." : "Altres persones poden llegir la carpeta de dades.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Canvieu els permisos a 0770 perquè altres persones no puguin veure el contingut de la carpeta.",
    "Your data directory must be an absolute path." : "La carpeta de dades ha de ser un camí absolut.",
    "Check the value of \"datadirectory\" in your configuration." : "Comproveu el valor de «datadirectory» en la configuració.",
    "Your data directory is invalid." : "La carpeta de dades no és vàlida.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Assegureu-vos que hi hagi un fitxer anomenat \"%1$s\" a l'arrel del directori de dades. Hauria de tenir el contingut: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "L'acció «%s» no està admesa o implementada.",
    "Authentication failed, wrong token or provider ID given" : "No s'ha pogut autenticar; s'ha proporcionat un testimoni o un ID de proveïdor incorrecte",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Falten paràmetres per a completar la sol·licitud. Els paràmetres que falten són: «%s»",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "L'ID «%1$s» ja l'utilitza el proveïdor de federació del núvol «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "El proveïdor de federació del núvol amb l'ID «%s» no existeix.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir el tipus de blocatge %d a «%s».",
    "Storage unauthorized. %s" : "L'emmagatzematge no està autoritzat. %s",
    "Storage incomplete configuration. %s" : "La configuració de l'emmagatzematge està incompleta. %s",
    "Storage connection error. %s" : "S'ha produït un error de connexió amb l'emmagatzematge. %s",
    "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
    "Storage connection timeout. %s" : "S'ha superat el temps d'espera de la connexió d'emmagatzematge. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Per permetre que aquesta comprovació s'executi, heu d'assegurar-vos que el vostre servidor web es pot connectar a si mateix. Per tant, ha de ser capaç de resoldre i connectar-se a almenys un dels seus `trusted_domains` o `overwrite.cli.url`. Aquest error pot ser el resultat d'una manca de concordança de DNS del servidor o d'una regla de tallafoc de sortida.",
    "Transcribe audio" : "Transcripció d'àudio",
    "Transcribe the things said in an audio" : "Transcriu les coses dites en un àudio",
    "Audio input" : "Entrada d'àudio",
    "The audio to transcribe" : "L'àudio a transcriure",
    "Transcription" : "Transcripció",
    "The transcribed text" : "El text transcrit",
    "ContextAgent" : "ContextAgent",
    "Chat with an agent" : "Xat amb un agent",
    "Chat message" : "Missatge de xat",
    "A chat message to send to the agent." : "Un missatge de xat per enviar a l'agent.",
    "Confirmation" : "Confirmació",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Si confirmar les accions sol·licitades anteriorment: 0 per a la denegació i 1 per a la confirmació.",
    "Conversation token" : "Testimoni de conversa",
    "A token representing the conversation." : "Un testimoni que representa la conversa.",
    "Generated response" : "Resposta generada",
    "The response from the chat model." : "La resposta del model de xat.",
    "The new conversation token" : "El nou testimoni de conversa",
    "Send this along with the next interaction." : "Envieu-ho juntament amb la següent interacció.",
    "Requested actions by the agent" : "Accions sol·licitades per l'agent",
    "Actions that the agent would like to carry out in JSON format." : "Accions que l'agent vol dur a terme en format JSON.",
    "Context write" : "Escriptura de context",
    "Writes text in a given style based on the provided source material." : "Escriu text en un estil determinat basant-se en el material font proporcionat.",
    "Writing style" : "Estil d'escriptura",
    "Demonstrate a writing style that you would like to immitate" : "Demostra un estil d'escriptura que t'agradaria imitar",
    "Source material" : "Material d'origen",
    "The content that would like to be rewritten in the new writing style" : "El contingut que voldria ser reescrit amb el nou estil d'escriptura",
    "Generated text" : "Text generat",
    "The generated text with content from the source material in the given style" : "El text generat amb contingut del material d'origen en l'estil donat",
    "Emoji generator" : "Generador d'emojis",
    "Takes text and generates a representative emoji for it." : "Pren text i genera un emoji representatiu.",
    "The text to generate an emoji for" : "El text per a generar un emoji",
    "Generated emoji" : "Emoji generat",
    "The generated emoji based on the input text" : "L'emoji generat a partir del text d'entrada",
    "Generate image" : "Generar imatge",
    "Generate an image from a text prompt" : "Genereu una imatge a partir d'una sol·licitud de text",
    "Prompt" : "Indicador",
    "Describe the image you want to generate" : "Descriu la imatge que vols generar",
    "Number of images" : "Nombre d'imatges",
    "How many images to generate" : "Quantes imatges generar",
    "Output images" : "Imatges de sortida",
    "The generated images" : "Les imatges generades",
    "Free text to text prompt" : "Text lliure per indicador de text",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Executa una indicació arbitraria mitjançant un model de llengua que retorna una resposta",
    "Describe a task that you want the assistant to do or ask a question" : "Descriu una tasca que vols que faci l'assistent o fes una pregunta",
    "Generated reply" : "Resposta generada",
    "The generated text from the assistant" : "El text generat per l'assistent",
    "Change Tone" : "Canvia el to",
    "Change the tone of a piece of text." : "Canvia el to d'un fragment de text.",
    "Write a text that you want the assistant to rewrite in another tone." : "Escriu un text que vols que l'assistent torni a escriure en un altre to.",
    "Desired tone" : "To desitjat",
    "In which tone should your text be rewritten?" : "En quin to s'ha de reescriure el teu text?",
    "The rewritten text in the desired tone, written by the assistant:" : "El text reescrit en el to desitjat, escrit per l'assistent:",
    "Chat" : "Xat",
    "Chat with the assistant" : "Xat amb l'assistent",
    "System prompt" : "Indicador del sistema",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definir regles i supòsits que l'assistent ha de seguir durant la conversa.",
    "Chat history" : "Historial de xat",
    "The history of chat messages before the current message, starting with a message by the user" : "L'historial dels missatges de xat abans del missatge actual, començant amb un missatge de l'usuari",
    "Response message" : "Missatge de resposta",
    "The generated response as part of the conversation" : "La resposta generada com a part de la conversa",
    "Chat with tools" : "Xat amb eines",
    "Chat with the language model with tool calling support." : "Xat amb el model de llengua amb suport de crida d'eines.",
    "Tool message" : "Missatge de l'eina",
    "The result of tool calls in the last interaction" : "El resultat de les crides d'eines en l'última interacció",
    "Available tools" : "Eines disponibles",
    "The available tools in JSON format" : "Les eines disponibles en format JSON",
    "The response from the chat model" : "La resposta del model de xat",
    "Tool calls" : "Crides d'eines",
    "Tools call instructions from the model in JSON format" : "Les eines criden instruccions del model en format JSON",
    "Formalize text" : "Formalitzar el text",
    "Takes a text and makes it sound more formal" : "Pren un text i el fa sonar més formal",
    "Write a text that you want the assistant to formalize" : "Escriu un text que vulguis que l'assistent formalitzi",
    "Formalized text" : "Text formalitzat",
    "The formalized text" : "El text formalitzat",
    "Generate a headline" : "Generar un titular",
    "Generates a possible headline for a text." : "Genera un titular possible per a un text.",
    "Original text" : "Text original",
    "The original text to generate a headline for" : "El text original per a generar un títol",
    "The generated headline" : "El títol generat",
    "Proofread" : "Revisat",
    "Proofreads a text and lists corrections" : "Corregeix un text i enumera les correccions",
    "Text" : "Text",
    "The text to proofread" : "El text a corregir",
    "Corrections" : "Correccions",
    "The corrections that should be made in your text" : "Les correccions que s'han de fer al vostre text",
    "Reformulate text" : "Reformular el text",
    "Takes a text and reformulates it" : "Agafa un text i el reformula",
    "Write a text that you want the assistant to reformulate" : "Escriu un text que vulguis que l'assistent reformuli",
    "Reformulated text" : "Text reformulat",
    "The reformulated text, written by the assistant" : "El text reformulat, escrit per l'assistent",
    "Simplify text" : "Simplifica el text",
    "Takes a text and simplifies it" : "Agafa un text i el simplifica",
    "Write a text that you want the assistant to simplify" : "Escriu un text que vulguis que l'assistent simplifiqui",
    "Simplified text" : "Text simplificat",
    "The simplified text" : "El text simplificat",
    "Summarize" : "Resumeix",
    "Summarizes a text" : "Resumeix un text",
    "The original text to summarize" : "El text original per resumir",
    "Summary" : "Resum",
    "The generated summary" : "El resum generat",
    "Extract topics" : "Extreu els temes",
    "Extracts topics from a text and outputs them separated by commas" : "Extreu temes d'un text i els envia separats per comes",
    "The original text to extract topics from" : "El text original per extreure temes",
    "Topics" : "Temes",
    "The list of extracted topics" : "La llista de temes extrets",
    "Translate" : "Tradueix",
    "Translate text from one language to another" : "Tradueix text d'una llengua a un altre",
    "Origin text" : "Text d'origen",
    "The text to translate" : "El text a traduir",
    "Origin language" : "Llengua d'origen",
    "The language of the origin text" : "La llengua del text d'origen",
    "Target language" : "Llengua de destinació",
    "The desired language to translate the origin text in" : "La llengua desitjada per traduir el text d'origen",
    "Result" : "Resultat",
    "The translated text" : "Copia el text traduït",
    "Free prompt" : "Sol·licitud lliure",
    "Runs an arbitrary prompt through the language model." : "Executa una sol·licitud arbitrària mitjançant el model de llengua.",
    "Generate headline" : "Genera un titular",
    "Summarizes text by reducing its length without losing key information." : "Resumeix el text reduint-ne la longitud sense perdre la informació clau.",
    "Extracts topics from a text and outputs them separated by commas." : "Extreu els temes d'un text i els retorna separats per comes.",
    "Education Edition" : "Edició educativa",
    "File name is a reserved word" : "El nom del fitxer és una paraula reservada",
    "File name contains at least one invalid character" : "El nom del fitxer conté almenys un caràcter no vàlid",
    "File name is too long" : "El nom del fitxer és massa llarg",
    "Users" : "Usuaris",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartit «%2$s» amb vós i vol afegir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartit «%2$s» amb vós i vol afegir",
    "»%s« added a note to a file shared with you" : "%s ha afegit una nota a un fitxer compartit amb vós",
    "Open »%s«" : "Obre «%s»",
    "%1$s shared »%2$s« with you" : "%1$s ha compartit «%2$s» amb vós",
    "%1$s shared »%2$s« with you." : "%1$s ha compartit «%2$s» amb vós.",
    "Click the button below to open it." : "Feu clic en el botó següent per a obrir-ho.",
    "File is currently busy, please try again later" : "El fitxer està ocupat actualment; torneu-ho a provar més tard",
    "Cannot download file" : "No es pot baixar el fitxer",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegureu-vos que hi hagi un fitxer anomenat «.ocdata» en l'arrel de la carpeta de dades.",
    "Path contains files shared with you" : "El camí conté fitxers compartits amb tu"
},
"nplurals=2; plural=(n != 1);");
